def get_video_by_id(id: str) -> str:
    """
    Calculate the great circle distance between two points on the
    earth (specified in decimal degrees), returns the distance in
    meters.
    All arguments must be of equal length.
    :param id: video id
    :return: will return an object
    """

    return int(id) * 2
